@@ -1,6 +1,6 @@
 package Bundle::InterchangeKitchenSink;
 
-$VERSION = '1.13';
+$VERSION = '1.14';
 
 1;
 
@@ -16,66 +16,24 @@ C<perl -MCPAN -e 'install Bundle::InterchangeKitchenSink'>
 
 =head1 CONTENTS
 
-Digest::MD5
-
-Digest::SHA1
-
-MIME::Base64
-
-MIME::Lite
-
-JSON
-
-URI::URL
-
-HTML::Tagset
-
-HTML::Entities
-
-HTML::Parser
-
-Bundle::LWP
-
-IO::Scalar
-
-Parse::RecDescent
-
-OLE::Storage_Lite
-
-Term::ReadKey
-
-Term::ReadLine::Perl
-
-Image::Size
-
-DBI
-
-Safe::Hole
-
-Set::Crontab
-
-Text::Query
-
-Tie::ShadowHash
-
-Business::UPS
-
-Storable
-
-Net::IP::Match::Regexp
-
-Spreadsheet::ParseExcel
-
-Spreadsheet::WriteExcel
+Bundle::Interchange
 
 Archive::Tar
 
 Archive::Zip
 
+Authen::Captcha
+
+Business::UPS
+
 Compress::Zlib
 
 Crypt::SSLeay
 
+Digest::SHA1
+
+HTML::Parser
+
 IO::Stty
 
 IO::Tty
@@ -84,12 +42,6 @@ SOAP::Lite
 
 Time::HiRes
 
-Authen::Captcha
-
-Digest::Bcrypt
-
-Crypt::Random
-
 =head1 DESCRIPTION
 
 This bundle installs the prerequisites for Interchange 5 as well as some
